@@ -37,7 +37,7 @@ for dir in {}:
   except OSError as ose:
     if str(ose) == '[Errno 17] EEXIST':
       if not {}:
-        print('    {{}} exist'.format(dir))
+        print('- {{}} exist'.format(dir))
     else:
       print(ose)
 '''
@@ -72,11 +72,15 @@ def list_all_files_and_dirs(includes, excludes):
 		splited_path = os.path.split(file)[0].split(os.path.sep)
 
 		for index in range(len(splited_path) + 1):
-			full_path = os.path.sep.join(splited_path[:index + 1])
+			full_path = os.path.sep.join(splited_path[:index])
 
 			if full_path not in dir_list and full_path:
 				dir_list.append(full_path)
 
+	for items in [file_list, dir_list, bad_list]:
+		for index, item in enumerate(items):
+			items[index] = item.replace('\\', '/')
+
 	file_list.sort()
 	dir_list.sort()
 	bad_list.sort()
@@ -192,7 +196,7 @@ def ab(options, files):
 
 	for index, file in enumerate(include_files, start=1):
 		if not options.quiet:
-			print(f'    uploading {file} ({index}/{len(include_files)})')
+			print(f'- uploading {file} ({index}/{len(include_files)})')
 
 		pyboard.fs_put(os.path.join(temp_dir.name if temp_dir else '', file), file)
 
